@@ -41,8 +41,8 @@ sub aggregate {
     my $agent = Plagger::UserAgent->new;
     my $res = $agent->fetch($url, $self);
 
-    if ($res->http_response->is_error) {
-        $context->log(error => "GET $url failed: " . $res->status_line);
+    if ($res->is_error) {
+        $context->log(error => "GET $url failed: " . $res->status);
         return;
     }
 
