@@ -44,10 +44,9 @@ sub aggregate {
     }
 
     my $content = decode_content($res);
-    my $title   = extract_title($content);
 
     my $feed = Plagger::Feed->new;
-    $feed->title($title);
+    $feed->title($args->{feed}->title || extract_title($content));
     $feed->link($url);
 
     if( my $re = $args->{match} ) {
@@ -62,12 +61,12 @@ sub aggregate {
             my $text = $parser->get_trimmed_text('/a');
             next if !$text || $text eq '[IMG]';
 
-            my $url = URI->new_abs($token->[1]->{href}, $url);
-            next if $seen{$url->as_string}++;
+            my $item_url = URI->new_abs($token->[1]->{href}, $url);
+            next if $seen{$item_url->as_string}++;
 
             my $entry = Plagger::Entry->new;
             $entry->title($text);
-            $entry->link($url);
+            $entry->link($item_url);
             $feed->add_entry($entry);
 
             $context->log(debug => "Add $token->[1]->{href} ($text)");
@@ -83,7 +82,7 @@ sub aggregate {
 
             my $entry = Plagger::Entry->new;
             $entry->title($title);
-            $entry->link($href);
+            $entry->link(URI->new_abs($href, $url));
             $feed->add_entry($entry);
 
             $context->log(debug => "Add $href ($title)");
