@@ -22,7 +22,7 @@ sub add_feed {
 sub finalize {
     my($self, $context) = @_;
 
-    my $body = $self->templatize($context, $self->{__feeds});
+    my $body = $self->templatize('psp.tt', { feeds => $self->{__feeds} });
     my $file = $self->conf->{output_file};
 
     $context->log(info => "Output HTML to $file");
@@ -31,14 +31,5 @@ sub finalize {
     close $out;
 }
 
-sub templatize {
-    my($self, $context, $feeds) = @_;
-    my $tt = $context->template();
-    $tt->process('psp.tt', {
-        feeds => $feeds,
-    }, \my $out) or $context->error($tt->error);
-    $out;
-}
-
 1;
 
