@@ -14,10 +14,20 @@ sub new {
 
 sub init { }
 
+sub id_for {
+    my($self, $entry) = @_;
+
+    if ($entry->date) {
+        return join ":", $entry->permalink, $entry->date;
+    } else {
+        return $entry->permalink;
+    }
+}
+
 sub is_new {
     my($self, $entry) = @_;
 
-    my $exists = $self->find_entry($entry->permalink) or return 1;
+    my $exists = $self->find_entry( $self->id_for($entry) ) or return 1;
 
     if ($self->{compare_body}) {
         return $exists ne $entry->digest;
@@ -28,7 +38,7 @@ sub is_new {
 
 sub add {
     my($self, $entry) = @_;
-    $self->create_entry($entry->permalink, $entry->digest);
+    $self->create_entry( $self->id_for($entry), $entry->digest );
 }
 
 sub find_entry   { }
